==> nextcloud-16.0.5.tgz: nextcloud/apps/firstrunwizard/l10n/pt_PT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! For example your email is needed to reset your password." : "Adicione a sua informação de perfil. Por exemplo, o seu e-mail é necessário para efectuar a reposição da sua chave.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente de PC",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "Connect your desktop apps to %s" : "Ligue as suas aplicações de PC para %s",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Download macOS/iOS configuration profile" : "Transferir perfil de configuração de macOS/iOS"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.10.tgz: nextcloud/apps/firstrunwizard/l10n/pt_PT.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copied!" : "Copiado!",
    "Not supported!" : "Não suportado!",
    "Press ⌘-C to copy." : "Pressionar ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Pressionar Ctrl-C para copiar.",
    "First run wizard" : "Wizard de arranque inicial",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adicione informação ao seu perfil! Definir uma image de perfil e um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adicione informação ao seu perfil! Defina um nome completo para facilitar o reconhecimento em todas as funcionalidades.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adicione informação ao seu perfil! Defina uma imagem de perfil para facilitar o reconhecimento em todas as funcionalidades.",
    "About" : "Sobre",
    "Get the apps to sync your files" : "Obtenha as aplicações para sincronizar os seus ficheiros",
    "Desktop client" : "Cliente de PC",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "Connect your desktop apps to %s" : "Ligue as suas aplicações de PC para %s",
    "Connect your calendar" : "Ligar o seu calendário",
    "Connect your contacts" : "Ligar os seus contactos",
    "Access files via WebDAV" : "Aceder aos ficheiros via WebDAV",
    "Download macOS/iOS configuration profile" : "Transferir perfil de configuração de macOS/iOS",
    "A safe home for all your data" : "Um local seguro para todos os seus dados",
    "Server address" : "Endereço do servidor",
    "Copy link" : "Copiar hiperligação",
    "Add your profile information! For example your email is needed to reset your password." : "Adicione a sua informação de perfil. Por exemplo, o seu e-mail é necessário para efectuar a reposição da sua chave.",
    "Previous" : "Anterior",
    "Next" : "Próximo"
},
"nplurals=2; plural=(n != 1);");
